module.exports = {
  id: 42,
  slug: 'name',
  admin: true,
  avatar: undefined,
  date: new Date(),
  article: {
    title: 'Name',
    description: 'Something longer goes here',
    body: 'There once was someone who viewed tests, and they were amazing.'
  },
  comments: [{
    body: 'Nothing is safe inside of an array',
    tags: ['hello']
  }, {
    body: '',
    tags: [null]
  }, {
    body: null,
    tags: [null]
  }]
}