module.exports = {
  "_id": "5883cb02b768a81f86fb467e",
  "votes": {
    "funny": 0,
    "useful": 0,
    "cool": 0
  },
  "user_id": "KZuaJtFindQM9x2ZoMBxcQ",
  "review_id": "WExNE-f93SL4D1q8s9QWKg",
  "stars": 1,
  "date": "2013-07-14",
  "text": "This place is absolute garbage...  Half of the tees are not available, including all the grass tees.  It is cash only, and they sell the last bucket at 8, despite having lights.  And if you finish even a minute after 8, don't plan on getting a drink.  The vending machines are sold out (of course) and they sell drinks inside, but close the drawers at 8 on the dot.  There are weeds grown all over the place.  I noticed some sort of batting cage, but it looks like those are out of order as well.  Someone should buy this place and turn it into what it should be.",
  "type": "review",
  "business_id": "cE27W9VPgO88Qxe4ol6y_g",
  "approved_by": null
}